@@ -52,6 +52,7 @@ struct header{
  float srow_z[4] ;    
  char intent_name[16];
  char magic[4] ;      
+ char extension[4] ;      
 
 
 };
@@ -123,7 +124,8 @@ void read_nifti_header_wrap_JM(char **name,
 			      float *srow_y,
 			      float *srow_z,
 			      char **intent_name,
-			      char **magic
+			      char **magic,
+			      char **extension
 
 			      ) 
      
@@ -136,55 +138,59 @@ void read_nifti_header_wrap_JM(char **name,
   read4byte_JM(sizeof_hdr, name[0], swapbytes, 1, 0L, 0);
   readchar_JM(data_type[0], name[0], swapbytes, 10, 4L, 0);
   readchar_JM(db_name[0], name[0], swapbytes, 18, 14L, 0);
-  read4byte_JM(extents, name[0], swapbytes, 1, 32L, 1);
-  read2byte_JM(&tmp, name[0], swapbytes, 1, 36L, 1);
+  read4byte_JM(extents, name[0], swapbytes, 1, 32L, 0);
+  read2byte_JM(&tmp, name[0], swapbytes, 1, 36L, 0);
   *session_error = (int) tmp;
   readchar_JM(regular[0], name[0], swapbytes, 1, 38L, 0);
   readchar_JM(dim_info[0], name[0], swapbytes, 1, 39L, 0);
-  read2byte_JM(tmp1, name[0], swapbytes, 8, 40L, 1);
+  read2byte_JM(tmp1, name[0], swapbytes, 8, 40L, 0);
   for(i = 0; i < 8; i++){dim[i] = (int) tmp1[i];}
-  readfloat_JM(intent_p1, name[0], swapbytes, 1, 56L, 1);
-  readfloat_JM(intent_p2, name[0], swapbytes, 1, 60L, 1);
-  readfloat_JM(intent_p3, name[0], swapbytes, 1, 64L, 1);
-  read2byte_JM(&tmp, name[0], swapbytes, 1, 68L, 1);
+  readfloat_JM(intent_p1, name[0], swapbytes, 1, 56L, 0);
+  readfloat_JM(intent_p2, name[0], swapbytes, 1, 60L, 0);
+  readfloat_JM(intent_p3, name[0], swapbytes, 1, 64L, 0);
+  read2byte_JM(&tmp, name[0], swapbytes, 1, 68L, 0);
   *intent_code = (int) tmp;
-  read2byte_JM(&tmp, name[0], swapbytes, 1, 70L, 1);
+  read2byte_JM(&tmp, name[0], swapbytes, 1, 70L, 0);
   *datatype = (int) tmp;
-  read2byte_JM(&tmp, name[0], swapbytes, 1, 72L, 1);
+  read2byte_JM(&tmp, name[0], swapbytes, 1, 72L, 0);
   *bitpix = (int) tmp;
-  read2byte_JM(&tmp, name[0], swapbytes, 1, 74L, 1);
+  read2byte_JM(&tmp, name[0], swapbytes, 1, 74L, 0);
   *slice_start = (int) tmp;
-  readfloat_JM(pixdim, name[0], swapbytes, 8, 76L, 1);
-  readfloat_JM(vox_offset, name[0], swapbytes, 1, 108L, 1);
-  readfloat_JM(scl_slope, name[0], swapbytes, 1, 112L, 1);
-  readfloat_JM(scl_inter, name[0], swapbytes, 1, 116L, 1);
-  read2byte_JM(&tmp, name[0], swapbytes, 1, 120L, 1);
+  readfloat_JM(pixdim, name[0], swapbytes, 8, 76L, 0);
+  readfloat_JM(vox_offset, name[0], swapbytes, 1, 108L, 0);
+  readfloat_JM(scl_slope, name[0], swapbytes, 1, 112L, 0);
+  readfloat_JM(scl_inter, name[0], swapbytes, 1, 116L, 0);
+  read2byte_JM(&tmp, name[0], swapbytes, 1, 120L, 0);
   *slice_end = (int) tmp;
   readchar_JM(slice_code[0], name[0], swapbytes, 1, 122L, 0);
   readchar_JM(xyzt_units[0], name[0], swapbytes, 1, 123L, 0);
-  readfloat_JM(cal_max, name[0], swapbytes, 1, 124L, 1);
-  readfloat_JM(cal_min, name[0], swapbytes, 1, 128L, 1);
+  readfloat_JM(cal_max, name[0], swapbytes, 1, 124L, 0);
+  readfloat_JM(cal_min, name[0], swapbytes, 1, 128L, 0);
   readfloat_JM(slice_duration, name[0], swapbytes, 1, 132L, 1);
   readfloat_JM(toffset, name[0], swapbytes, 1, 136L, 1);
   read4byte_JM(glmax, name[0], swapbytes, 1, 140L ,1);
   read4byte_JM(glmin, name[0], swapbytes, 1, 144L, 1);
   readchar_JM(descrip[0], name[0], swapbytes, 80, 148L, 0);
   readchar_JM(aux_file[0], name[0], swapbytes, 24, 228L, 0);
-   read2byte_JM(&tmp, name[0], swapbytes, 1, 252L, 1);
+   read2byte_JM(&tmp, name[0], swapbytes, 1, 252L, 0);
   *qform_code = (int) tmp;
-  read2byte_JM(&tmp, name[0], swapbytes, 1, 254L, 1);
+  read2byte_JM(&tmp, name[0], swapbytes, 1, 254L, 0);
   *sform_code = (int) tmp;
-  readfloat_JM(quatern_b, name[0], swapbytes, 1, 256L, 1);
-  readfloat_JM(quatern_c, name[0], swapbytes, 1, 260L, 1);
-  readfloat_JM(quatern_d, name[0], swapbytes, 1, 264L, 1);
-  readfloat_JM(qoffset_x, name[0], swapbytes, 1, 268L, 1);
-  readfloat_JM(qoffset_y, name[0], swapbytes, 1, 272L, 1);
-  readfloat_JM(qoffset_z, name[0], swapbytes, 1, 276L, 1);
-  readfloat_JM(srow_x, name[0], swapbytes, 4, 280L, 1);
-  readfloat_JM(srow_y, name[0], swapbytes, 4, 296L, 1);
-  readfloat_JM(srow_z, name[0], swapbytes, 4, 312L, 1);
+  readfloat_JM(quatern_b, name[0], swapbytes, 1, 256L, 0);
+  readfloat_JM(quatern_c, name[0], swapbytes, 1, 260L, 0);
+  readfloat_JM(quatern_d, name[0], swapbytes, 1, 264L, 0);
+  readfloat_JM(qoffset_x, name[0], swapbytes, 1, 268L, 0);
+  readfloat_JM(qoffset_y, name[0], swapbytes, 1, 272L, 0);
+  readfloat_JM(qoffset_z, name[0], swapbytes, 1, 276L, 0);
+  readfloat_JM(srow_x, name[0], swapbytes, 4, 280L, 0);
+  readfloat_JM(srow_y, name[0], swapbytes, 4, 296L, 0);
+  readfloat_JM(srow_z, name[0], swapbytes, 4, 312L, 0);
   readchar_JM(intent_name[0], name[0], swapbytes, 16, 328L, 0);
   readchar_JM(magic[0], name[0], swapbytes, 4, 344L, 0);
+  readchar_JM(extension[0], name[0], swapbytes, 1, 348L, 0);
+  readchar_JM(extension[1], name[0], swapbytes, 1, 349L, 0);
+  readchar_JM(extension[2], name[0], swapbytes, 1, 350L, 0);
+  readchar_JM(extension[3], name[0], swapbytes, 1, 351L, 0);
 
 
 
@@ -239,6 +245,7 @@ void read_nifti_header_JM(struct header *head, char *name, int *swapbytes)
   readfloat_JM(&head->srow_z[0], name, swapbytes, 4, 312L, 1);
   readchar_JM(head->intent_name, name, swapbytes, 16, 328L, 0);
   readchar_JM(head->magic, name, swapbytes, 4, 344L, 0);
+  readchar_JM(head->extension, name, swapbytes, 4, 348L, 0);
 
 
 }
